@@ -1,18 +1,18 @@
-/* $Id: demowindow.cc 617 2006-05-11 19:50:59Z murrayc $ */
+/* $Id: demowindow.cc 1082 2009-01-19 17:55:19Z murrayc $ */
 
 /* Copyright (C) 2001 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -32,6 +32,13 @@
 #include <cerrno>
 #include <stdio.h>
 
+#include <cstring>
+
+using std::isspace;
+using std::strlen;
+
+#include "demo-common.h"
+
 #ifdef NEED_FLOCKFILE_PROTO
 extern "C" void flockfile (FILE *);
 #endif
@@ -276,7 +283,7 @@ void DemoWindow::load_file(const std::string& filename)
     FILE* file = fopen (filename.c_str(), "r");
     if (!file)
     {
-      std::string installed = /* DEMOCODEDIR + G_DIR_SEPARATOR_S + */ filename;
+      std::string installed = demo_find_file(filename);
       file = fopen (installed.c_str(), "r");
     }
 
